@@ -976,13 +976,13 @@ class MainWindow(QMainWindow, WindowMixin):
             self.canvas.setShapeVisible(shape, item.checkState() == Qt.Checked)
 
     # Callback functions:
-    # Importante. 
+    # Importante.
     def newShapeStoma(self, text='stoma'):
         """Pop-up and give focus to the label editor.
 
         position MUST be in global coordinates.
         """
-        # Jónathan. 
+        # Jónathan.
         # Estas líneas las he comentado yo.
         # if not self.useDefaultLabelCheckbox.isChecked() or not self.defaultLabelTextLine.text():
         #    if len(self.labelHist) > 0:
@@ -1486,7 +1486,6 @@ class MainWindow(QMainWindow, WindowMixin):
                     path = os.path.dirname(ustr(self.filePath)) if self.filePath else '.'
                     imgFileName = os.path.basename(self.filePath)
                     img = os.path.join(path, imgFileName)
-                    print(img)
                     detectStoma.mainImage(img)
                     if isinstance(img, (tuple, list)):
                         img = img[0]
@@ -1787,4 +1786,4 @@ def main():
 
 
 if __name__ == '__main__':
-    sys.exit(main())
+    sys.exit(main())
\ No newline at end of file
