@@ -8,6 +8,8 @@ import sys
 import os
 import urllib.request
 from tqdm import tqdm
+import shutil
+
 
 confThreshold = 0.25  #Confidence threshold
 nmsThreshold = 0.45   #Non-maximum suppression threshold
@@ -27,7 +29,7 @@ def getOutputsNames(net):
 
 
 # Remove the bounding boxes with low confidence using non-maxima suppression
-def postprocess(frame, outs):
+def postprocess(frame, outs, conf):
     frameHeight = frame.shape[0]
     frameWidth = frame.shape[1]
 
@@ -44,7 +46,7 @@ def postprocess(frame, outs):
             scores = detection[5:]
             classId = np.argmax(scores)
             confidence = scores[classId]
-            if confidence > confThreshold:
+            if confidence > conf:
                 center_x = int(detection[0] * frameWidth)
                 center_y = int(detection[1] * frameHeight)
                 width = int(detection[2] * frameWidth)
@@ -58,7 +60,8 @@ def postprocess(frame, outs):
     # Perform non maximum suppression to eliminate redundant overlapping boxes with
     # lower confidences.
     newBoxes=[]
-    indices = cv.dnn.NMSBoxes(boxes, confidences, confThreshold, nmsThreshold)
+    newConfi = []
+    indices = cv.dnn.NMSBoxes(boxes, confidences, conf, nmsThreshold)
     for i in indices:
         i = i[0]
         #box = boxes[i]
@@ -66,9 +69,11 @@ def postprocess(frame, outs):
         #top = box[1]
         #width = box[2]
         #height = box[3]
+        newConfi.append(confidences[i])
         newBoxes.append(boxes[i])
+
         # drawPred(classIds[i], confidences[i], left, top, left + width, top + height)
-    return newBoxes
+    return newBoxes, newConfi
 
 
 #Load names of classes
@@ -109,7 +114,7 @@ def prettify(elem):
     return reparsed.toprettyxml(indent="  ")
 
 
-def generateXML(filename,outputPath,w,h,d,boxes):
+def generateXML(filename,outputPath,w,h,d,boxes,confidences):
     top = ET.Element('annotation')
     childFolder = ET.SubElement(top, 'folder')
     childFolder.text = 'images'
@@ -129,7 +134,7 @@ def generateXML(filename,outputPath,w,h,d,boxes):
     childDepth.text = str(d)
     childSegmented = ET.SubElement(top, 'segmented')
     childSegmented.text = str(0)
-    for box in boxes:
+    for box, con in zip(boxes,confidences):
         category = 'stoma'
         (x,y,wb,hb) = box
         childObject = ET.SubElement(top, 'object')
@@ -141,6 +146,8 @@ def generateXML(filename,outputPath,w,h,d,boxes):
         childTruncated.text = '0'
         childDifficult = ET.SubElement(childObject, 'difficult')
         childDifficult.text = '0'
+        childConfidence = ET.SubElement(childObject, 'confidence')
+        childConfidence.text = str(con)
         childBndBox = ET.SubElement(childObject, 'bndbox')
         childXmin = ET.SubElement(childBndBox, 'xmin')
         childXmin.text = str(x)
@@ -153,37 +160,38 @@ def generateXML(filename,outputPath,w,h,d,boxes):
     return prettify(top)
 
 
-def generateXMLFromImage(imagePath):
-    net = cv.dnn.readNetFromDarknet(modelConfiguration, modelWeights)
+def generateXMLFromImage(imagePath, conf):
+    #net = cv.dnn.readNetFromDarknet(modelConfiguration, modelWeights)
+    net = cv.dnn.readNet(modelWeights, modelConfiguration)
     net.setPreferableBackend(cv.dnn.DNN_BACKEND_OPENCV)
     net.setPreferableTarget(cv.dnn.DNN_TARGET_CPU)
-    im = cv.VideoCapture(imagePath)
-    hasFrame, frame = im.read()
-    wI, hI, d = frame.shape
-    tam = min(wI,hI)
-    if tam>=0 and tam<=624:
-        inpWidth = 416
-        inpHeight = 416
-    elif tam>624 and tam<=1040:
-        inpWidth = 832
-        inpHeight = 832
-    else:
-        inpWidth = 1248
-        inpHeight = 1248
-    blob = cv.dnn.blobFromImage(frame, 1 / 255, (inpWidth, inpHeight), [0, 0, 0], 1, crop=False)
-
+    #im = cv.VideoCapture(imagePath)
+    #hasFrame, frame = im.read()
+    frame = cv.imread(str(imagePath))
     # Sets the input to the network
-    net.setInput(blob)
+    palabra1 = "width"
+    palabra2 = "height"
+    with open(modelConfiguration) as f:
+        for linea in f:
+            if palabra1 in linea:
+                partes =linea.split('=')
+                inpWidth = int(partes[1])
+            elif palabra2 in linea:
+                partes =linea.split('=')
+                inpHeight = int(partes[1])
 
+    blob = cv.dnn.blobFromImage(frame, 1 / 255, (1024, 1024), [0, 0, 0], 1, crop=False)
+    #blob = cv.dnn.blobFromImage(frame, 1 / 255, ("600", "600"), [0, 0, 0], 1, crop=False)
+    net.setInput(blob)
     # Runs the forward pass to get output of the output layers
     outs = net.forward(getOutputsNames(net))
-
+    boxes, confidences = postprocess(frame, outs, conf)
+    wI, hI, d = frame.shape
     # Remove the bounding boxes with low confidence
-    boxes = postprocess(frame, outs)
-
+    #boxes = postprocess(frame, outs)
     #wI, hI, d = frame.shape
     file = open(imagePath[0:imagePath.rfind(".")] + ".xml", "w")
-    file.write(generateXML(imagePath[0:imagePath.rfind(".")], "", wI, hI, d, boxes))
+    file.write(generateXML(imagePath[0:imagePath.rfind(".")], "", wI, hI, d, boxes, confidences))
     file.close()
 
 
@@ -194,9 +202,10 @@ def mainImage(imagePath):
     #arg2 = sys.argv[2]
     #arg3 = sys.argv[3]
     #print(prueba.genera_vector_aleatorio(arg1,arg2,arg3))
-    generateXMLFromImage(imagePath)
+    generateXMLFromImage(imagePath,confThreshold)
 
 def mainDataset(imagesPath):
     images = list(paths.list_files(imagesPath, validExts=(".jpg", ".jpeg", ".png", ".bmp", ".tiff", ".tif")))
     for image in images:
-        generateXMLFromImage(image)
+        image = image.replace("\\ ", " ")
+        generateXMLFromImage(image,confThreshold)
